***********
 CHANGELOG
***********

Unreleased
==========

0.5.1
=====

Library
-------

* This version changes the name of entry IDs from the nonsensical ``uid`` to
  ``eid`` (Entry ID) everywhere in the code, including the property
  ``Entry.uid`` and all method names.
